@@ -24,9 +24,7 @@ class AgaveProvider(OAuth2Provider):
         return dict(
             email=data.get("email"),
             username=data.get("username", ""),
-            name=(
-                (data.get("first_name", "") + " " + data.get("last_name", "")).strip()
-            ),
+            name=(f"{data.get('first_name', '')} {data.get('last_name', '')}".strip()),
         )
 
     def get_default_scope(self):
