@@ -13,17 +13,14 @@ class Auth0OAuth2Adapter(OAuth2Adapter):
     settings = app_settings.PROVIDERS.get(provider_id, {})
     provider_base_url = settings.get("AUTH0_URL")
 
-    access_token_url = "{0}/oauth/token".format(provider_base_url)
-    authorize_url = "{0}/authorize".format(provider_base_url)
-    profile_url = "{0}/userinfo".format(provider_base_url)
+    access_token_url = f"{provider_base_url}/oauth/token"
+    authorize_url = f"{provider_base_url}/authorize"
+    profile_url = f"{provider_base_url}/userinfo"
 
     def complete_login(self, request, app, token, response):
-        extra_data = (
-            get_adapter()
-            .get_requests_session()
-            .get(self.profile_url, params={"access_token": token.token})
-            .json()
-        )
+        with get_adapter().get_requests_session() as sess:
+            resp = sess.get(self.profile_url, params={"access_token": token.token})
+            extra_data = resp.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
